.. chemsynthcalc documentation master file, created by
   sphinx-quickstart on Sun Sep 11 16:13:47 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

chemsynthcalc
=========================================
ChemSynthCalc stands for Chemical Synthesis Calculator.

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Contents
--------

.. toctree::